@@ -1,4 +1,7 @@
 package Fey::ORM::Mock::Action;
+BEGIN {
+  $Fey::ORM::Mock::Action::VERSION = '0.05';
+}
 
 use strict;
 use warnings;
@@ -70,7 +73,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Factory and base class for recorded actions
+
+
 
 =pod
 
@@ -78,6 +83,10 @@ __END__
 
 Fey::ORM::Mock::Action - Factory and base class for recorded actions
 
+=head1 VERSION
+
+version 0.05
+
 =head1 DESCRIPTION
 
 This class acts as a factory and base class for actions which are
@@ -115,13 +124,18 @@ These are convenience methods for checking an action's type.
 
 =head1 AUTHOR
 
-Dave Rolsky, C<< <autarch@urth.org> >>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Dave Rolsky, All Rights Reserved.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
