@@ -1,4 +1,7 @@
 package Fey::ORM::Mock::Action::Update;
+BEGIN {
+  $Fey::ORM::Mock::Action::Update::VERSION = '0.05';
+}
 
 use strict;
 use warnings;
@@ -26,7 +29,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A record of an update
+
+
 
 =pod
 
@@ -34,6 +39,10 @@ __END__
 
 Fey::ORM::Mock::Action::Update - A record of an update
 
+=head1 VERSION
+
+version 0.05
+
 =head1 DESCRIPTION
 
 This class represents a record of a call to C<update()> for a
@@ -56,13 +65,18 @@ objects passed to C<update()>
 
 =head1 AUTHOR
 
-Dave Rolsky, C<< <autarch@urth.org> >>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Dave Rolsky, All Rights Reserved.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
