@@ -1,4 +1,7 @@
 package Fey::ORM::Mock::Recorder;
+BEGIN {
+  $Fey::ORM::Mock::Recorder::VERSION = '0.05';
+}
 
 use strict;
 use warnings;
@@ -52,7 +55,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Records the history of changes for a class
+
+
 
 =pod
 
@@ -60,6 +65,10 @@ __END__
 
 Fey::ORM::Mock::Recorder - Records the history of changes for a class
 
+=head1 VERSION
+
+version 0.05
+
 =head1 DESCRIPTION
 
 This object is used to store a record of the changes for each class.
@@ -92,13 +101,18 @@ Clears the records for all classes.
 
 =head1 AUTHOR
 
-Dave Rolsky, C<< <autarch@urth.org> >>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Dave Rolsky, All Rights Reserved.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
