@@ -1,4 +1,7 @@
 package Fey::ORM::Mock::Seeder;
+BEGIN {
+  $Fey::ORM::Mock::Seeder::VERSION = '0.05';
+}
 
 use strict;
 use warnings;
@@ -22,7 +25,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Stores seeded data for future object construction
+
+
 
 =pod
 
@@ -30,6 +35,10 @@ __END__
 
 Fey::ORM::Mock::Seeder - Stores seeded data for future object construction
 
+=head1 VERSION
+
+version 0.05
+
 =head1 DESCRIPTION
 
 This object is used to store seeded data for constructors. You will
@@ -54,13 +63,18 @@ Returns the next set of values for given class, if any exist.
 
 =head1 AUTHOR
 
-Dave Rolsky, C<< <autarch@urth.org> >>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Dave Rolsky, All Rights Reserved.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
