@@ -1,4 +1,7 @@
 package Fey::Object::Mock::Schema;
+BEGIN {
+  $Fey::Object::Mock::Schema::VERSION = '0.05';
+}
 
 use strict;
 use warnings;
@@ -33,7 +36,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Mock schema class subclass of Fey::Object::Schema
+
+
 
 =pod
 
@@ -41,6 +46,10 @@ __END__
 
 Fey::Object::Mock::Schema - Mock schema class subclass of Fey::Object::Schema
 
+=head1 VERSION
+
+version 0.05
+
 =head1 DESCRIPTION
 
 When you use L<Fey::ORM::Mock> to mock a schema, this class will
@@ -65,13 +74,18 @@ schema.
 
 =head1 AUTHOR
 
-Dave Rolsky, C<< <autarch@urth.org> >>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Dave Rolsky, All Rights Reserved.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
